@@ -1,20 +1,22 @@
 package MooX::Role::Parameterized;
-{
-    $MooX::Role::Parameterized::VERSION = '0.082';
-}
+
 use strict;
 use warnings;
 use Carp;
 
 # ABSTRACT: MooX::Role::Parameterized - roles with composition parameters
 use MooX::Role::Parameterized::Proxy;
-use Exporter qw(import);
+use Moo::Role       qw();
+use Exporter        qw(import);
 use Module::Runtime qw(use_module);
+
+our $VERSION = "0.100";
+
 our @EXPORT = qw(role method apply hasp);
 
 my %code_for;
 
-sub hasp { carp "hasp deprecated"; }
+sub hasp { croak "hasp is deprecated and should not be used"; }
 
 sub apply {
     my ( $role, $args, %extra ) = @_;
@@ -23,7 +25,7 @@ sub apply {
 
     $args = [$args] if ref($args) ne ref( [] );
 
-    my $target = $extra{target} // caller;
+    my $target = defined( $extra{target} ) ? $extra{target} : caller;
 
     {
         no strict 'refs';
@@ -31,32 +33,38 @@ sub apply {
 
         # necessary for magic
         *{ $role . '::hasp' } = sub {
+            carp 'hasp deprecated, use $mop->has instead.';
 
-            #        carp 'hasp deprecated, use $object->has instead.';
             goto &{ $target . '::has' };
         };
         *{ $role . '::method' } = sub {
+            carp 'method deprecated, use $mop->method instead.';
 
-            #        carp 'method deprecated, use $object->method instead.';
             my ( $name, $code ) = @_;
+
             no strict 'refs';
-            *{"$target\::$name"} = $code;
+
+            *{ $target . '::' . $name } = $code;
         };
     }
-    my $p =
-      MooX::Role::Parameterized::Proxy->new( target => $target, role => $role );
+
+    my $p = MooX::Role::Parameterized::Proxy->new(
+        target => $target,
+        role   => $role
+    );
+
     $code_for{$role}->( $_, $p ) foreach ( @{$args} );
 
-    use_module('Moo::Role')->apply_roles_to_package( $target, $role );
+    Moo::Role->apply_roles_to_package( $target, $role );
 }
 
-sub role(&) {
+sub role(&) {    ##no critic (Subroutines::ProhibitSubroutinePrototypes)
     my $package = (caller)[0];
 
     $code_for{$package} = shift;
 }
 
-sub method { carp "hasp deprecated"; }
+sub method { croak "method is deprecated and should not be used"; }
 
 1;
 __END__
@@ -65,7 +73,7 @@ __END__
 
 MooX::Role::Parameterized - roles with composition parameters
 
-=head1 SYNOPSYS
+=head1 SYNOPSIS
 
     package My::Role;
 
@@ -86,8 +94,10 @@ MooX::Role::Parameterized - roles with composition parameters
     package My::Class;
 
     use Moo;
-    # experimental way of add roles
-    use MooX::Role::Parameterized::With My::Role => {
+
+    use MooX::Role::Parameterized::With;
+
+    with 'My::Role' => {
         attr => 'baz',
         method => 'run'
     };
